from django.db import models
from django.contrib.auth.models import User
from django.contrib.auth.models import AbstractUser
from django.utils import timezone


# Create your models here.

ACCOUNT_TYPES = [
        ('Savings', 'Savings'),
        ('Checkings', 'Checkings'),
    ]




class User(AbstractUser):
    balance = models.DecimalField(max_digits=18, decimal_places=2, default=0.0)
    active = models.BooleanField(default=False)
    country = models.CharField(max_length=50, default="null")
    next_of_kin = models.CharField(max_length=50, default="Name of kin")
    security_validation_phrase = models.CharField(max_length=50, default="Make standard")
    address = models.CharField(max_length=50, default="New")
    authentication_pin = models.IntegerField(default=0000)
    state_of_origin = models.CharField(max_length=60, default="null")
    phone_number = models.CharField(max_length=50, default="null")
    
    
    
    
    
    
    
    def __str__(self):
        return self.username
    

class UserDetails(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE)
    routing_number = models.CharField(max_length=30)
    account_number = models.CharField(max_length=30, default="40523868")
    
    credit_detail = models.DecimalField(max_digits=6, decimal_places=2, default=0.0)
    
    available_credit = models.DecimalField(max_digits=18, decimal_places=2, default=0.0)
    income = models.DecimalField(max_digits=18, decimal_places=2, default=0.0)
    expense = models.DecimalField(max_digits=18, decimal_places=2, default=0.0)
    
    
    def __str__(self):
        return self.user.username
    
class Linked(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE)
    balance = models.DecimalField(max_digits=18, decimal_places=2, default=0.0)
    
    routing_number = models.CharField(max_length=30)
    first_name = models.CharField(max_length=30)
    last_name = models.CharField(max_length=30)
    
    def __str__(self):
        return self.user.username
    
    
    


TRANSACTION_STATUS = (
    ('pending', 'Pending'),
    ('processing', 'Processing'),
    ('reversed', 'Reversed'),
    ('successful', 'Successful')
)

TRANSACTION_TYPE = (
    ('deposit', 'Deposit'),
    ('transfer', 'Transfer') ,
)


class Transaction(models.Model):
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    amount = models.DecimalField(decimal_places=2, max_digits=20)
    routing_number = models.CharField(max_length=20)
    account_number = models.CharField(max_length=20,default="0234584831")
    account_name = models.CharField(max_length=50)
    bank_name = models.CharField(max_length=50)
    recurring = models.BooleanField(default=False)
    status = models.CharField(choices=TRANSACTION_STATUS, default="pending" ,max_length=10)
    transaction_type = models.CharField(choices=TRANSACTION_TYPE, default="Transfer", max_length=10)
    date = models.DateTimeField(default=timezone.now)
    transaction_id = models.CharField(max_length=50, default="123432")
    description = models.CharField(max_length=60, default="bills payment")  
    session_id =   models.CharField(max_length=60, default="0x000000000000000827282")  
    
    class Meta:
        ordering = ['-date']
    def __str__(self):
        return self.bank_name
    
    
    

class UserProfile(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE)
    profile_picture = models.FileField(upload_to='profile_pictures/', blank=True, null=True)

    def __str__(self):
        return self.user.username
    

import datetime
CARD_TYPE_CHOICES = [
    ('visa', 'Visa'),
    ('mastercard', 'MasterCard'),
    ('amex', 'American Express'),
    ('discover', 'Discover'),
]
class BankCard(models.Model):
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    card_balance = models.DecimalField(decimal_places=2, max_digits=20, default=0.00)
    cardholder_name = models.CharField(max_length=60, default='John Doe')
    card_type = models.CharField(max_length=10, choices=CARD_TYPE_CHOICES, default='visa')
    expiry_date = models.DateField(default=datetime.date.today)
    cvv = models.CharField(max_length=4,  default='392')
    card_no = models.CharField(max_length=30, default='7181 8181 1111 9919')
    def __str__(self):
        return self.user.username


class Accounts(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE)
    bank_name =models.CharField(max_length=60, default='Trust Wealth Savings')
    account_status = models.BooleanField(default=True)
    account_type = models.CharField(max_length=60, choices=ACCOUNT_TYPES, default="Checkings")


    def __str__(self):
            return self.user.username